//
// $Id$
//
#include <TApplication.h>
#include "MapTest.h"
#include <iostream>
#ifndef ICON_PATH
#define ICON_PATH "."
#endif

//____________________________________________________________________
ClassImp(MapTest);

//____________________________________________________________________
MapTest::MapTest(const char* pname, const TGWindow *p, UInt_t w, UInt_t h)
  : TGMainFrame(p, w, h)
{
  //__________________________________________________________________  
  // Layout

  //__________________________________________________________________  
  // Picture pool and picture
  fPicPool = new TGPicturePool(gClient, ICON_PATH);
  const TGPicture* pic = fPicPool->GetPicture(pname);
  cout << "Pic h: " << pic->GetHeight() << " w: " << pic->GetWidth()
       << endl;

  //__________________________________________________________________
  // Image map
  fImageMap = new TGImageMap(this, pic);
  fImageMap->SetToolTipText("Map image", 1);
  fLHMap = new TGLayoutHints(kLHintsLeft|kLHintsTop);
  AddFrame(fImageMap, fLHMap);
  Connect("OnMouseOver(Int_t)", "MapTest", this, "DoOverRegion(Int_t)");
  Connect("DoubleClicked()", "MapTest", this, "DoMapClicked()");
  
  //__________________________________________________________________
  // Regions 
  Int_t* x = new Int_t[4]; 
  Int_t* y = new Int_t[4];
  x[0] = 10; x[1] = 10;  x[2] = 100; x[3] = 100;
  y[0] = 10; y[1] = 100, y[2] = 100; y[3] = 10;
  TGRegion region1(4, x, y);
  if (region1.IsNull())
    cout << "Region is null" << endl;
  fImageMap->AddRegion(region1, 1);
  fImageMap->SetToolTipText(1, "Region 1", 1);

  //__________________________________________________________________
  // Quit button 
  fQuitButton = new TGTextButton(this, "&Quit", 150);
  fLHButton = new TGLayoutHints(kLHintsRight|kLHintsBottom);
  AddFrame(fQuitButton, fLHButton);
  fQuitButton->Connect("Clicked()", "MapTest", this, "DoButton()");

  //__________________________________________________________________
  // Properties and mapping
  SetWindowName("Map Test");
  MapSubwindows();
  Resize(GetDefaultSize());
  MapWindow();  
}

//____________________________________________________________________
MapTest::~MapTest() 
{
  delete fQuitButton;
  delete fImageMap;
  delete fPicPool;
  delete fLHButton;
  delete fLHMap;
}

//____________________________________________________________________
void MapTest::CloseWindow()
{
  cout << "MapTest::CloseWindow" << endl;
  gApplication->Terminate(0);
}

//____________________________________________________________________
void MapTest::DoButton()
{
  cout << "MapTest::DoButton" << endl;
  CloseWindow();
}

//____________________________________________________________________
void MapTest::DoOverRegion(Int_t id) 
{
  cout << "Over " << id << endl;
}

//____________________________________________________________________
void MapTest::DoMapClicked() 
{
  cout << "Map clicked" << endl;
}
