#if !defined INPUTDIALOG_H
#define INPUTDIALOG_H
//
// This file contains the class InputDialog.
// An InputDialog object prompts for an input string using a simple
// dialog box. The InputDialog class is also a good example of how
// to use the ROOT GUI classes via the interpreter. Since interpreted
// classes can not call virtual functions via base class pointers, all
// GUI objects are used by composition instead of by inheritance.
//
// This file contains also some utility functions that use
// the InputDialog class to either get a string, integer or
// floating point number. There are also two functions showing
// how to use the file open and save dialogs. The utility functions are:
//
//  char *OpenFileDialog()
//  char *SaveFileDialog()
//  char *GetStringDialog( char *prompt,  char *defval)
// Int_t GetIntegerDialog( char *prompt, Int_t defval)
// Float_t GetFloatDialog( char *prompt, Float_t defval)
//
// To use the InputDialog class and the utility functions you just
// have to load the dialogs.C file as follows:
// .L dialogs.C
//
// Now you can use them like:
// {
//     char *file = OpenFileDialog();
//    Int_t run   = GetIntegerDialog("Give run number:", 0);
//    Int_t event = GetIntegerDialog("Give event number:", 0);
//    printf("analyse run %d, event %d from file %s\n", run ,event, file);
// }
//

///////////////////////////////////////////////////////////////////////////
//                                                                       //
// Input Dialog Widget                                                   //
//                                                                       //
///////////////////////////////////////////////////////////////////////////

#include <TGTextEntry.h>
#include <TGTextBuffer.h>

char *GetStringDialog( char *prompt,  char *defval) ;
Int_t GetIntegerDialog( char *prompt, Int_t defval) ;
Float_t GetFloatDialog( char *prompt, Float_t defval) ;


class InputDialog //: public TGTransientFrame 
{
  
 private:
  TGTransientFrame *fuDialog;  // transient frame, main dialog window
  TGTextEntry      *fTE;      // text entry widget containing
  TList            *fWidgets; // keep track of widgets to be deleted in dtor
  char             *fRetStr;  // address to store return string


 public:
  InputDialog( char *prompt,  char *defval, char *retstr);
  virtual ~InputDialog();
  virtual Bool_t ProcessMessage(Long_t msg, Long_t parm1, Long_t parm2);

 public:
  ClassDef(InputDialog,0) 
};

#endif
